var __create = Object.create;
var __defProp = Object.defineProperty;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __markAsModule = (target) => __defProp(target, "__esModule", {value: true});
var __exportStar = (target, module2, desc) => {
  if (module2 && typeof module2 === "object" || typeof module2 === "function") {
    for (let key of __getOwnPropNames(module2))
      if (!__hasOwnProp.call(target, key) && key !== "default")
        __defProp(target, key, {get: () => module2[key], enumerable: !(desc = __getOwnPropDesc(module2, key)) || desc.enumerable});
  }
  return target;
};
var __toModule = (module2) => {
  if (module2 && module2.__esModule)
    return module2;
  return __exportStar(__markAsModule(__defProp(module2 != null ? __create(__getProtoOf(module2)) : {}, "default", {value: module2, enumerable: true})), module2);
};

// src/cli/svite.ts
var import_cac = __toModule(require("cac"));

// package.json
var version = "0.9.0-1";
var repository = {
  type: "git",
  url: "git+https://github.com/svitejs/svite.git"
};

// src/cli/create.ts
var path = __toModule(require("path"));
var fs = __toModule(require("fs"));

// ../vite-plugin-svelte/package.json
var version2 = "0.9.3";

// src/cli/create.ts
var templatesPath = "packages/templates";
var log = console;
async function updatePkg(dir) {
  try {
    const pkgFile = path.join(dir, "package.json");
    const pkg = require(pkgFile);
    pkg.name = path.basename(dir);
    pkg.devDependencies["@svitejs/vite-plugin-svelte"] = `^${version2}`;
    fs.writeFileSync(pkgFile, JSON.stringify(pkg, null, 2));
  } catch (e) {
    throw e;
  }
}
async function addVsCodePluginRecommendation(dir) {
  fs.mkdirSync(path.join(dir, ".vscode"));
  fs.writeFileSync(path.join(dir, ".vscode", "extensions.json"), `{
  "recommendations": ["svelte.svelte-vscode"]
}
`);
}
var templates = [
  "minimal",
  "routify-mdsvex",
  "windicss",
  "preprocess-auto"
];
async function create(options) {
  let template = options.template;
  if (!templates.includes(template)) {
    log.error(`invalid template ${template}. Valid: ${JSON.stringify(templates)}`);
    return;
  }
  if (options.typescript) {
    template = `${template}-ts`;
  }
  const targetDir = path.join(process.cwd(), options.targetDir || `svite-${template.replace("/", "-")}`);
  const degit = require("degit");
  const githubRepo = repository.url.match(/github\.com\/(.*).git/)[1];
  const degitPath = `${githubRepo}/${templatesPath}/${template}#main`;
  const degitOptions = {
    force: options.force,
    verbose: options.debug,
    mode: "tar"
  };
  if (options.debug) {
    log.debug(`degit ${degitPath}`, degitOptions);
  }
  const emitter = degit(degitPath, degitOptions);
  emitter.on("info", (info) => {
    log.info(info.message);
  });
  emitter.on("warn", (warning) => {
    log.warn(warning.message);
  });
  emitter.on("error", (error) => {
    log.error(error.message, error);
  });
  await emitter.clone(targetDir);
  await updatePkg(targetDir);
  await addVsCodePluginRecommendation(targetDir);
  log.info(`created ${targetDir}`);
}

// src/cli/svite.ts
var cli = import_cac.cac("svite");
cli.command("create [targetDir]", 'create a new project. If you do not specify targetDir, "./svite-<template>" will be used').option("--t, --template <string>", `template for new project. ${JSON.stringify(templates)}`, {default: templates[0]}).option("--ts, --typescript", "enable typescript support for svelte", {
  default: false
}).option("-f, --force", "force operation even if targetDir exists and is not empty", {default: false}).option("-d, --debug", "more verbose logging", {default: false}).action(async (targetDir, options) => {
  options.targetDir = targetDir;
  await create(options);
});
cli.help();
cli.version(version);
cli.parse(process.argv, {run: false});
async function main() {
  if (cli.matchedCommand) {
    await cli.runMatchedCommand();
  } else {
    cli.outputHelp();
  }
}
main().catch((e) => {
  console.error("create failed", e);
  process.exit(1);
});
